/*
LTC2983_configuration_constants.h
Constants used to configure the LTC2983/4
Adapted from the Linduino reference code

Copyright (c) 2016, Dust Networks.  All rights reserved.
Subject to the terms of the OCSDK license - https://github.com/dustcloud/onchipsdk/blob/master/software_license_on-chip_sdk.pdf

Additionally - 

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

//**********************************************
// -- SENSOR TYPES --
//**********************************************
// Thermocouple
#define SENSOR_TYPE__TYPE_J_THERMOCOUPLE 0x00000001 << 27
#define SENSOR_TYPE__TYPE_K_THERMOCOUPLE 0x00000002 << 27
// Off-Chip Diode
#define SENSOR_TYPE__OFF_CHIP_DIODE 0x1C << 27

//**********************************************
// -- Thermocouple --
//**********************************************
// tc - cold junction ch
//#define TC_COLD_JUNCTION_CH_LSB 22
//#define TC_COLD_JUNCTION_CH__NONE 0b0 << 22
//#define TC_COLD_JUNCTION_CH__1 0b1 << 22
#define TC_COLD_JUNCTION_CH__2 0x00000002 << 22
//#define TC_COLD_JUNCTION_CH__3 0b11 << 22
#define TC_COLD_JUNCTION_CH__4 0x4 << 22
//#define TC_COLD_JUNCTION_CH__5 0b101 << 22
//#define TC_COLD_JUNCTION_CH__6 0b110 << 22
//#define TC_COLD_JUNCTION_CH__7 0b111 << 22
//#define TC_COLD_JUNCTION_CH__8 0b1000 << 22
//#define TC_COLD_JUNCTION_CH__9 0b1001 << 22
//#define TC_COLD_JUNCTION_CH__10 0b1010 << 22
// tc - differential?
//#define TC_DIFFERENTIAL_LSB 21
//#define TC_DIFFERENTIAL 0b0 << 21
#define TC_SINGLE_ENDED 0x00000001 << 21
// tc - open ckt detect?
//#define TC_OPEN_CKT_DETECT_LSB 20
//#define TC_OPEN_CKT_DETECT__NO 0b0 << 20
#define TC_OPEN_CKT_DETECT__YES 0x00000001 << 20
// tc - open ckt detect current
//#define TC_OPEN_CKT_DETECT_CURRENT_LSB 18
#define TC_OPEN_CKT_DETECT_CURRENT__10UA 0x00000000 << 18
//#define TC_OPEN_CKT_DETECT_CURRENT__100UA 0b1 << 18
//#define TC_OPEN_CKT_DETECT_CURRENT__500UA 0b10 << 18
//#define TC_OPEN_CKT_DETECT_CURRENT__1MA 0b11 << 18
// tc - custom address
#define TC_CUSTOM_ADDRESS_LSB 6
// tc - custom length-1
#define TC_CUSTOM_LENGTH_1_LSB 0
// tc - custom values
#define TC_CUSTOM_VALUES_LSB 31

//**********************************************
// -- Off-Chip Diode --
//**********************************************
// diode - differential?
#define DIODE_DIFFERENTIAL_LSB 26
#define DIODE_DIFFERENTIAL 0 << 26
#define DIODE_SINGLE_ENDED 1 << 26
// diode - num readings
#define DIODE_NUM_READINGS_LSB 25
#define DIODE_NUM_READINGS__2 0 << 25
#define DIODE_NUM_READINGS__3 1 << 25
// diode - averaging on?
#define DIODE_AVERAGING_ON_LSB 24
#define DIODE_AVERAGING_OFF 0 << 24
#define DIODE_AVERAGING_ON 1 << 24
// diode - current
#define DIODE_CURRENT_LSB 22
#define DIODE_CURRENT__10UA_40UA_80UA 0 << 22
#define DIODE_CURRENT__20UA_80UA_160UA 1 << 22
#define DIODE_CURRENT__40UA_160UA_320UA 2 << 22
#define DIODE_CURRENT__80UA_320UA_640UA 3 << 22
// diode - ideality factor(eta)
#define DIODE_IDEALITY_FACTOR_LSB 0

//**********************************************
// -- GLOBAL CONFIGURATION CONSTANTS --
//**********************************************
#define REJECTION__50_60_HZ 0x00
#define REJECTION__60_HZ    0x01
#define REJECTION__50_HZ    0x02
#define TEMP_UNIT__C        0x00
#define TEMP_UNIT__F        0x04

//**********************************************
// -- STATUS BYTE CONSTANTS --
//**********************************************
#define SENSOR_HARD_FAILURE 0x80
#define ADC_HARD_FAILURE    0x40
#define CJ_HARD_FAILURE     0x20
#define CJ_SOFT_FAILURE     0x10
#define SENSOR_ABOVE        0x08
#define SENSOR_BELOW        0x04
#define ADC_RANGE_ERROR     0x02
#define VALID               0x01

//**********************************************
// -- ADDRESSES --
//**********************************************
#define VOUT_CH_BASE    0x060
#define READ_CH_BASE    0x010


