/*
 LTC2983_support_functions.c
 Copyright (c) 2016, Dust Networks.  All rights reserved.
 
 Subject to the terms of the OCSDK license - https://github.com/dustcloud/onchipsdk/blob/master/software_license_on-chip_sdk.pdf
*/
//C includes
#include <stdint.h>
#include <stdio.h>
#include <math.h>
#include "string.h"

//app includes
#include "LTC2983_configuration_constants.h"
#include "LTC2983_support_functions.h"
#include "Thermocouple.h"

//SDK includes
#include "dn_common.h"
#include "dn_system.h"
#include "dn_spi.h"
#include "dnm_ucli.h"

// -------- externals
extern dc2399_app_vars_t     app_v;

// -----------------------------------------------------------------
//                  Memory  functions
// -----------------------------------------------------------------
void assignChannel(INT8U channel_number, INT32U channel_assignment_data) {
   INT32U start_address = 0x200+4*(channel_number-1);
   INT8U  i;
   
   for(i=0; i< sizeof(INT32U); i++){
      rwByte(start_address + i, MEM_WRITE, (channel_assignment_data >> 8*(3-i)) & 0xFF);
   }
}

void rwByte(INT16U start_address, INT8U mode, INT8U data) {
   dn_error_t   dnErr;
   
   memset(&app_v.spiRxBuffer, 0, sizeof(app_v.spiRxBuffer));
   memset(&app_v.spiTxBuffer, 0, sizeof(app_v.spiTxBuffer));
   
   // set up SPI Tx buffer with channel data
   app_v.command.command = mode;                                 
   app_v.command.address = htons(start_address);     
   app_v.command.data[0] = data;  
       
   app_v.spiTransfer.transactionLen = sizeof(app_v.command.command) + sizeof(app_v.command.address) + 1;
   
   memcpy(&app_v.spiTxBuffer, &app_v.command, sizeof(app_v.command));
   
   dnErr = dn_ioctl(  
                     DN_SPI_DEV_ID,
                     DN_IOCTL_SPI_TRANSFER,
                     &app_v.spiTransfer,
                     sizeof(app_v.spiTransfer)
   );        
}

// -----------------------------------------------------------------
// 					Channel conversion
// -----------------------------------------------------------------
void convertChannel(INT8U channel_number){
   dn_error_t   dnErr;
   INT8U        data; 
   
   rwByte(STATUS_REG, MEM_WRITE, 0x80 | channel_number); 
}

// -----------------------------------------------------------------
//         Reading
// -----------------------------------------------------------------
INT32U getRawResults(INT32U base_address, INT8U channel_number) {
   dn_error_t   dnErr;
   INT32U       address = base_address+4*(channel_number-1);
   INT8U        fault;   
   int          i;
   INT32U       temperature = 0; 
   
   rwByte(address, MEM_READ, 00);
   fault = app_v.spiRxBuffer[3];
   if (fault & 0x1 != 1){
       printFault(fault);
   }
   
   for(i=1; i< sizeof(INT32U); i++){
      rwByte(address + i, MEM_READ, 00);
      temperature |= app_v.spiRxBuffer[3] << (8*(3-i) & 0xFF);
   }
   
   return (temperature);
}

// Translate the fault byte into usable fault data and print it out
void printFault(INT8U fault_byte) {
  
   if(fault_byte & 0x01 != VALID){
      dnm_ucli_printf("FAULT=");
      switch (fault_byte & 0xFE){
      case SENSOR_HARD_FAILURE:
         dnm_ucli_printf("SENSOR HARD FALURE\r\n");
         break;
      case ADC_HARD_FAILURE:
         dnm_ucli_printf("ADC HARD FALURE\r\n");
         break;
      case CJ_HARD_FAILURE:
         dnm_ucli_printf("CJ HARD FALURE\r\n");
         break;
      case CJ_SOFT_FAILURE:
         dnm_ucli_printf("CJ_SOFT_FAILURE\r\n");
         break;
      case SENSOR_ABOVE:
         dnm_ucli_printf("SENSOR ABOVE\r\n");
         break;
      case SENSOR_BELOW:
         dnm_ucli_printf("SENSOR BELOW\r\n");
         break;
      case ADC_RANGE_ERROR:
         dnm_ucli_printf("ADC_RANGE_ERROR\r\n");
         break;
      case 0xFE:
         dnm_ucli_printf("INVALID SETUP\r\n");
         break;
      default:
         break;
   }
  }
}